# {{service}} with Tailscale Integration

This project sets up a {{service}} instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your {{service}} instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
your-project/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
└── {{service}}/
    └── config/         # {{service}} configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone <repository-url>
   cd <repository-name>
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations

4. Configure {{service}}
    - See {{service_docs}} for configuration options

5. Start the Services
    ```bash
    docker-compose up -d
    ```

## Services

### {{service}}-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: {{service}}-ts
- Hostname: {{service}}
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### {{service}}

- Depends on {{service}}-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://{{service}}.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://{{service}}.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs {{service}}-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment the Docker socket volume mapping in the service to enable Docker integrations:
    ```yaml
    - /var/run/docker.sock:/var/run/docker.sock
    ```
- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 3000:3000
    ```
- Stopping the Services
    ```bash
    docker-compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs {{service}}-ts
    docker logs {{service}}
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting
## Notes
- The {{service}} service uses the Tailscale service's network stack via network_mode: service:{{service}}-ts
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
- Tailscale documentation: https://tailscale.com/kb/
- {{service}} documentation: {{service_docs}}
